app

package
v0.0.0-...-eea0a58 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2024 License: GPL-3.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MetalInMetalPolicy

func MetalInMetalPolicy(metal string) bool

func Render

func Render(ctx context.Context, comp templ.Component) string

You should only care about this function for rendering the templates Returns the rendered HTML as a string for the swapping in the frontend

Types

type App

type App struct {
	Ctx       context.Context
	Groupings []data_pipeline.Grouping
}

func NewApp

func NewApp() *App

func (*App) GetDropArea

func (app *App) GetDropArea() string

func (*App) GetModelContent

func (app *App) GetModelContent(id string, expanded bool) string

func (*App) GetModels

func (app *App) GetModels(sortingMetal string) string

func (*App) OpenFileDialog

func (app *App) OpenFileDialog()

func (*App) Startup

func (app *App) Startup(ctx context.Context)

type Component

type Component struct {
	Html string
}

func (*Component) Write

func (c *Component) Write(p []byte) (int, error)

Write is a method that satisfies the io.Writer interface

Jump to